# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-08-06 07:51
from __future__ import unicode_literals

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Activity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=200, null=True, verbose_name="nom de l'activité")),
                ('is_public', models.NullBooleanField(verbose_name='est public')),
                ('has_perm', models.NullBooleanField(verbose_name='inscription de permanents')),
                ('min_perm', models.PositiveSmallIntegerField(blank=True, null=True, verbose_name='nombre minimum de permanents')),
                ('max_perm', models.PositiveSmallIntegerField(blank=True, null=True, verbose_name='nombre maximum de permanents')),
                ('description', models.TextField(blank=True, help_text="Visible par tout le monde si l'événément est public.", null=True, verbose_name='description')),
                ('remarks', models.TextField(blank=True, help_text='Visible uniquement par les organisateurs.', null=True, verbose_name='remarques')),
                ('beginning', models.DateTimeField(verbose_name='heure de début')),
                ('end', models.DateTimeField(verbose_name='heure de fin')),
            ],
            options={
                'verbose_name': 'activité',
                'verbose_name_plural': 'activités',
            },
        ),
        migrations.CreateModel(
            name='ActivityTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, verbose_name='nom du tag')),
                ('is_public', models.BooleanField(help_text="Sert à faire une distinction dans l'affichage selon que le tag soit destiné au public ou à l'organisation.", verbose_name='est public')),
                ('color', models.CharField(help_text='Rentrer une couleur en hexadécimal (#XXX ou #XXXXXX).', max_length=7, validators=[django.core.validators.RegexValidator(message="La chaîne de caractère rentrée n'est pas une couleur en hexadécimal.", regex='^#(?:[0-9a-fA-F]{3}){1,2}$')], verbose_name='couleur')),
            ],
            options={
                'verbose_name': 'tag',
                'verbose_name_plural': 'tags',
            },
        ),
        migrations.CreateModel(
            name='ActivityTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=200, null=True, verbose_name="nom de l'activité")),
                ('is_public', models.NullBooleanField(verbose_name='est public')),
                ('has_perm', models.NullBooleanField(verbose_name='inscription de permanents')),
                ('min_perm', models.PositiveSmallIntegerField(blank=True, null=True, verbose_name='nombre minimum de permanents')),
                ('max_perm', models.PositiveSmallIntegerField(blank=True, null=True, verbose_name='nombre maximum de permanents')),
                ('description', models.TextField(blank=True, help_text="Visible par tout le monde si l'événément est public.", null=True, verbose_name='description')),
                ('remarks', models.TextField(blank=True, help_text='Visible uniquement par les organisateurs.', null=True, verbose_name='remarques')),
            ],
            options={
                'verbose_name': 'template activité',
                'verbose_name_plural': 'templates activité',
            },
        ),
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200, verbose_name="nom de l'évènement")),
                ('slug', models.SlugField(help_text="Seulement des lettres, des chiffres ou les caractères '_' ou '-'.", unique=True, verbose_name='identificateur')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='date de création')),
                ('description', models.TextField(verbose_name='description')),
                ('beginning_date', models.DateTimeField(help_text="date publique de l'évènement", verbose_name='date de début')),
                ('ending_date', models.DateTimeField(help_text="date publique de l'évènement", verbose_name='date de fin')),
                ('created_by', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='created_events', to=settings.AUTH_USER_MODEL, verbose_name='créé par')),
            ],
            options={
                'verbose_name': 'évènement',
                'verbose_name_plural': 'évènements',
            },
        ),
        migrations.CreateModel(
            name='Place',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, verbose_name='nom du lieu')),
                ('description', models.TextField(blank=True)),
                ('event', models.ForeignKey(blank=True, help_text="Si spécifié, l'instance du modèle est spécifique à l'évènement en question.", null=True, on_delete=django.db.models.deletion.CASCADE, to='event.Event', verbose_name='évènement')),
            ],
            options={
                'verbose_name': 'lieu',
                'verbose_name_plural': 'lieux',
            },
        ),
        migrations.AddField(
            model_name='activitytemplate',
            name='event',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, to='event.Event', verbose_name='évènement'),
        ),
        migrations.AddField(
            model_name='activitytemplate',
            name='places',
            field=models.ManyToManyField(blank=True, to='event.Place', verbose_name='lieux'),
        ),
        migrations.AddField(
            model_name='activitytemplate',
            name='tags',
            field=models.ManyToManyField(blank=True, to='event.ActivityTag', verbose_name='tags'),
        ),
        migrations.AddField(
            model_name='activitytag',
            name='event',
            field=models.ForeignKey(blank=True, help_text="Si spécifié, l'instance du modèle est spécifique à l'évènement en question.", null=True, on_delete=django.db.models.deletion.CASCADE, to='event.Event', verbose_name='évènement'),
        ),
        migrations.AddField(
            model_name='activity',
            name='event',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, to='event.Event', verbose_name='évènement'),
        ),
        migrations.AddField(
            model_name='activity',
            name='parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='children', to='event.ActivityTemplate', verbose_name='template'),
        ),
        migrations.AddField(
            model_name='activity',
            name='places',
            field=models.ManyToManyField(blank=True, to='event.Place', verbose_name='lieux'),
        ),
        migrations.AddField(
            model_name='activity',
            name='staff',
            field=models.ManyToManyField(blank=True, related_name='in_perm_activities', to=settings.AUTH_USER_MODEL, verbose_name='permanents'),
        ),
        migrations.AddField(
            model_name='activity',
            name='tags',
            field=models.ManyToManyField(blank=True, to='event.ActivityTag', verbose_name='tags'),
        ),
    ]
